function ckFirmware()
%
% function sets parameters based on firmware version from hrp disk header
% called from write_hrp2xwavs.m
% called after read_rawHARPhead which gets firmware version
%
% 170531 smw

global PARAMS

% compression flag: no compression = 0, compression = 1
% firmwareVersion is 10 characters long
fver1 = PARAMS.head.firmwareVersion(1);
if strcmp(fver1,'1')
    PARAMS.cflag = 0;      % no compression
    PARAMS.ctype = -1;      % no compression type
elseif strcmp(fver1,'V')
    fver2 = str2num(PARAMS.head.firmwareVersion(2:5)); %#ok<ST2NM>
    if fver2 == 2.01            % OLD IDE HARP
        PARAMS.cflag = 0;      % no compression
        PARAMS.ctype = -1;      % no compression type
    elseif fver2 == 2.02        % Latest IDE HARP
        PARAMS.cflag = 1;      % compression
        fver3 = PARAMS.head.firmwareVersion(6);
        if strcmp(fver3,'Q')
            PARAMS.ctype = 0;
        elseif strcmp(fver3,'R') || strcmp(fver3,'r') 
            fver4 = PARAMS.head.firmwareVersion(7:10);
            if strcmp(fver4,'_SSD') % 'V2.02R_SSD'
                PARAMS.ctype = 0;
            else
                PARAMS.ctype = 1;      % 'V2.02R    '  or V2.02R_1
            end
        elseif  strcmp(fver3, 'S') || strcmp(fver3,'U') || ...
                strcmp(fver3, 'W') || strcmp(fver3, 'Z')
            PARAMS.ctype = 1;
        else
            disp('Error: unknown V2.02 IDE compression firmware version')
            disp(PARAMS.head.firmwareVersion)
            return
        end
    elseif fver2 == 2.05        % IDE 320 kHz sampling
        PARAMS.cflag = 1;       % ie compression
        PARAMS.ctype = 1;
    elseif fver2 == 2.20        % old longline HARP
        PARAMS.cflag = 1;       % ie compression
        PARAMS.ctype = 1;
    elseif fver2 == 2.10        % IDE 4 channel
        PARAMS.cflag = 0;      % no compression
        PARAMS.ctype = -1;      % no compression type
        PARAMS.nch = 4;
    elseif fver2 == 2.27        % miniHARP
        PARAMS.cflag = 1;       % ie compression
        PARAMS.ctype = 1;    
    elseif fver2 == 2.32        % LongLine HARP
        PARAMS.cflag = 1;       % ie compression
        PARAMS.ctype = 1;
    elseif fver2 == 2.60 || fver2 == 2.61 || fver2 == 2.62      % 320 kHz sampling SATA compression
        PARAMS.cflag = 1;
        PARAMS.ctype = 1;
    elseif fver2 == 2.70 || fver2 == 2.74   % SATA no compression
        PARAMS.cflag = 0;
        PARAMS.ctype = -1;
    elseif fver2 == 2.83 || fver2 == 2.84 || fver2 == 2.85 || fver2 == 2.86   % SATA compression
        PARAMS.cflag = 1;
        PARAMS.ctype = 1;
    elseif fver2 == 2.91  || fver2 == 2.94 || fver2 == 2.95 || fver2 == 2.96 % SATA 4 channel no compression
        PARAMS.cflag = 0;
        PARAMS.ctype = -1;
        PARAMS.nch = 4;
    else
        disp('Error: unknown compression firmware version')
        disp(PARAMS.head.firmwareVersion)
        return
    end
else
    disp('Error: Unknown firmware version:')
    disp(PARAMS.head.firmwareVersion)
    return
end