function [ odata, csectInfo ] = decompressRawHRP_170922(fid,rf,vflag,varargin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% decompressRawHRP.m
%
% Takes a raw HRP file and decompresses it.
%
% Parameters:
%       fid - input file identifier already fopen from calling code
%       rf - raw file (disk dump) number upon which to decompress
%       vflag - firmware/data version flag V2.02Q =0, V2.02R =1
%       varargin - extra variables used by hrp2xwav
% Return:
%       odata - vector of output data
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%  BJT 170607 added some additional debugging info
%             returns section info
%             tuned up bad block length catch
%  BJT 170922 added more error logging

global PARAMS

usb_ftp_flag=0;
byteblk = 512;
ftype = 1;

k=1;
while k < length(varargin)  %should this include datasamp/tailblk for 4 channel data?
    switch varargin{k}
        case 'usb_ftp_flag'
            usb_ftp_flag = varargin{k+1};
            k = k+2;
        case 'ftype'
            ftype = varargin{k+1};
            k = k+2;
        case 'filesize'
            filesize = varargin{k+1};
            k = k+2;
        case 'dvec'
            dvec = varargin{k+1};
            k = k+2;
        case 'ticks'
            ticks = varargin{k+1};
            k = k+2;
        case 'samplerate'
            samplerate = varargin{k+1};
            k = k+2;
        otherwise
            disp('Didn''t match varargs for decompressRawHRP, Check inputs');
            disp_msg('Didn''t match varargs for decompressRawHRP, Check inputs');
    end
end


dbflag = 0;     % debug display flag

bpsect = 512;       % bytes per sector

% skip to start of raw file
if usb_ftp_flag    
    nhrp = 1;
    status = 0;
    blkmx = floor(filesize/byteblk);
    Nsect = blkmx;
    vflag = vflag-2; %offset between old hrp2xwav and new decompressRawHRP
    rfStartByte = 1;
else
    status = fseek(fid,PARAMS.head.dirlist(rf,1)*bpsect,'bof');
    Nsect = PARAMS.head.dirlist(rf,10);
    samplerate = PARAMS.head.samplerate;
    rfStartByte = PARAMS.head.dirlist(rf,1)*bpsect;
end

if status ~= 0
    disp(['Error - failed fseek to byte ',num2str(PARAMS.head.dirlist(rf,1)*512)])
    return
end


% for error reporting
if ~isfield(PARAMS,'hrp')
    fprintf('PARAMS.hrp nonexistent...decompression error info will not be saved!\n');
    PARAMS.hrp.timingErrors = nan(10,5); % raw file, delta t, dnumber of previous timing header , dnumber of current timing header, byte location (from start of raw file )
    if PARAMS.cflag
        PARAMS.hrp.decompErrors = nan(10,6); % col1 = code, col2 = section number, col3 = byte location
        PARAMS.hrp.decompErrorTypes = { 1,'Sync Loss', ...  col4 = delta t, col5 = section number for next sync, col6 = byte location of next sync
            2,'Bad Block Tag', ... col4 = block type
            3,'Bad Block Length', ... col4 = block type, col5 = block length, col6 = correct block length
            4,'Bad Decompression Value', ... col4 = num bad samples
            };
        PARAMS.hrp.dUnit = 'Sections'; % timing header unit
    else
        PARAMS.hrp.dUnit = 'Sectors'; % timing header unit
    end
    PARAMS.hrp.ecntr = [ 0, 0, 0 ]; % counters for errors: timing errors, decompression errors, BWA
end


csector = 0;              % sector count
csection = 0;           % section count
cyy = 0; % init this hear, always added to csector in just in case we scan for sync losses
if usb_ftp_flag
    dvo = [dvec(1:5) dvec(6)+ticks/1000];
else
    dvo = [PARAMS.head.dirlist(rf,2:6) ...
        PARAMS.head.dirlist(rf,7)+0.001*PARAMS.head.dirlist(rf,8)];
end

dnumo = datenum(dvo);       % first old datenum is dirlist time
nBlksPerRawFile = 0;

% output vector
if samplerate == 320000
    Tnsamp = 14e6;    % total number of samples in one raw file
else
    Tnsamp = 15e6;
end
ncsect = Tnsamp/4000; % 4000 sample FIFO buffer
csectInfo = nan(ncsect,3); % compressed section times, start samp, end samp

odata = zeros(Tnsamp,1);  % pre-allocate memory for output data - this is very important for processing speed
sn1 = 1;    % sample number for beginning of section

% loop over sectors in raw file
% typically there will be multiple number of sectors (=>8) in ea
% Section, so kinda looping over Sections in integer number of
% sectors
while csector < Nsect
    
    csection = csection + 1;    
%     fprintf('csection = %d\tsector = %d of %d\n', csection,csector,Nsect);    

    rlen = 0;     % remaining number of bytes to read to end of Section
    [dv,dcount] = fread(fid,8,'uint8');
    
    % the following shouldn't be needed except for perhaps last file
    % left over from hrp2xwav on single ftp/usb raw files
    if dcount ~= 8
        disp('*************** EOF - Stopped Writing XWAV *******************')
        disp(['only read ',num2str(dcount),' values for timing header'])
        disp('Since less than 8, must be EOF')
        [msg,errnum] = ferror(fid);
        disp(['msg= ',msg,'  errnum= ',num2str(errnum)])
        break       % break out of while csector
    end
    if ftype == 1
        ticks = (little2big_2byte([dv(8) dv(7)]));
        dnum = datenum([dv(2) dv(1) dv(4) dv(3) dv(6) dv(5)+ 0.001.* ticks]);
    elseif ftype == 2
        ticks = 2^8*dv(7)+ dv(8);
        dnum = datenum([dv(1) dv(2) dv(3) dv(4) dv(5) dv(6)+ 0.001.* ticks]);
    end
    ddnum = dnum - dnumo;   % difference in datenum new - old
    dsec = ddnum * 24 * 60 * 60;        % section header times should be 0.020 sec apart
    dsec = round(1000*dsec)/1000;
    
    %             if samplerate == 200000
    %                 header_diff1 = 0.020;
    %                 header_diff2 = 0.020;
    %             elseif samplerate == 320000
    %                 header_diff1 = .012;
    %                 header_diff2 = .013;
    %             elseif samplerate == 2000
    %                 header_diff1 = 2.000;
    %                 header_diff2 = 2.000;
    if samplerate <= 200000 % should put a catch in here for millisecond rounding 
        header_diff1 = 4000/samplerate;
        header_diff2 = header_diff1;
    elseif samplerate == 320000
        header_diff1 = .012;
        header_diff2 = .013;
    else
        errordlg(['Unknown sampling rate: ' num2str(samplerate)]);
        return
    end
    
    if (dsec ~= header_diff1 || dsec ~= header_diff2) && dbflag
        disp([num2str(csection),'  ',...
            datestr(dnum,'yy mm dd HH MM SS FFF'),' - ',...
            datestr(dnumo,'yy mm dd HH MM SS FFF'),' = ',num2str(dsec)])
    end
    % check for time diff and report
    % 1.020 and -0.98 are from 2.02Q.  This has bee fixed in 2.02R
    % .013 & .012 is from 2.05A (320KHz)
    % 320KHz requires extra checks due to DL rounding off
    % millisecond fractions
    delTerr = 0;
    delTvals = unique([ header_diff1, header_diff2, ...
        header_diff1-1, 1+header_diff1,...
        header_diff2-1, 1+header_diff2, 0 ]);
    if ~ismember(dsec, delTvals)
        delTerr=1;
    end
%     if samplerate == 200000
%         if (dsec ~= 0.020 && dsec ~= 1.020  && dsec ~= -0.98 && ...
%                 dsec ~= 0)
%             delTerr = 1;
%         end
%     elseif samplerate == 320000
%         if (dsec ~= 0.012 && dsec ~= 0.013 && dsec ~= 0 && ...
%                 dsec ~= 1.013 && dsec ~= 1.012 && dsec ~= -0.987 ...
%                 && dsec ~= -0.988 )
%             delTerr = 1;
%         end
%     end
    
    if delTerr    
        pos = ftell(fid);
        rpos = ftell(fid)-rfStartByte;
        fprintf('\tTriton Error: Time difference between section headers is %6f\n', dsec); 
        fprintf('\t\tt1 = %s\n\t\tt2 = %s\n', ...
            datestr(dnumo,'yy mm dd HH MM SS FFF'),datestr(dnum,'yy mm dd HH MM SS FFF'));
        fprintf('\t\tcsection #%d, bytes to current section = %d\n', ...
            csection, rpos);
        fprintf('\tPosition = %d [ dec bytes ] || %s [ hex bytes ]\n', ...
            pos,dec2hex(pos));
        PARAMS.hrp.ecntr(1) = PARAMS.hrp.ecntr(1)+1;
        PARAMS.hrp.timingErrors(PARAMS.hrp.ecntr(1),:)= [rf, dsec, dnumo, dnum, rpos ];
    end
    
    % omit buffer wrap time -81.9s, as this is not a 'sync' loss
    dmin = -100;
    dmax = 100;
    if (dsec < dmin) || (dsec > dmax)   % if sync loss
        
        % give some feed back
%         disp(['Triton Error: sync loss at sector = ',num2str(csector),' section = ',num2str(csection)])
%         disp(['previous datetime: ',datestr(dnumo,'yy mm dd HH MM SS FFF')])
%         disp(['current  datetime: ',datestr(dnum,'yy mm dd HH MM SS FFF')])
%         disp(['diff = ',num2str(dsec),' seconds'])
        
        pos = ftell(fid);
        rpos = ftell(fid)-rfStartByte;
        disp(['csection= ',num2str(csection),' csector=  ',num2str(csector),...
            ' ',datestr(dnum),' ',num2str(ticks),' bn= ',num2str(bn),...
            ' rlen= ',num2str(rlen),'  blen= ',num2str(blen),'  btag= ',...
            num2str(btag),' Position= ',dec2hex(pos)])
        % fix output XWAV file
        dnsamp = 4000 - nsamp;      % difference number of samples of previous write
        % from Sector size
        if btag > 2^15             % check for 8-bit data
            dbyte = dnsamp;
        else        % 16-bit
            dbyte = 2*dnsamp;
        end
        disp(['nsamp = ',num2str(nsamp),'   dnsamp = ',num2str(dnsamp),'    dbyte = ',num2str(dbyte)])
        if dnsamp < 0
            sn1 = sn1 + dnsamp;    % jump back in output file
        elseif dnsamp > 0
            A = samp1 .* ones(dnsamp,1);
            odata(sn1-dnsamp:sn1-1) = A;
        end
        dsec0 = dsec;
        % search for next section timing header sync
        cyy = 0;
        while dsec < dmin || dsec > dmax
            fseek(fid,-7,0); % go back 7 bytes so that each read only advances 1 byte
            dv = fread(fid,8,'uint8');
            if ftype == 1
                ticks = (little2big_2byte([dv(8) dv(7)]));
                dnum = datenum([dv(2) dv(1) dv(4) dv(3) dv(6) dv(5)+ 0.001.* ticks]);
            elseif ftype == 2
                ticks = 2^8*dv(7)+ dv(8);
                dnum = datenum([dv(1) dv(2) dv(3) dv(4) dv(5) dv(6)+ 0.001.* ticks]);
            end
            ddnum = dnum - dnumo;   % difference in datenum new - old
            dsec = ddnum * 24 * 60 * 60;        % section header times should be 0.020 sec apart
            dsec = round(1000*dsec)/1000;
            cyy = cyy + 1;
            if cyy >= 30e6
                disp('stepping too far - exit')
                % save info on sync loss
                PARAMS.hrp.ecntr(2) = PARAMS.hrp.ecntr(2)+1;
                PARAMS.hrp.decompErrors(PARAMS.hrp.ecntr(2),1:6) = ...
                    [ 1, csection-1, rpos, dsec0, csection, ftell(fid) - 8 - rfStartByte,...
                    ddnum ];
                return
            end
        end  % end while
        
        csection0 = csection;
        disp(['jumped ahead ', num2str(cyy),' bytes to next timestamp'])
        disp(['new      datetime: ',datestr(dnum,'yy mm dd HH MM SS FFF')])
%         if dsec == 0.020 % only valid for 200kHz data 
%             disp(['Extra data: Jumped to next Section'])
%         elseif dsec == 0.040 % only valid for 200kHz data 
%             disp(['Missing data: Skip to 2nd next Section'])
%             csection = csection + 1;
%         else 
%             disp(['Triton Error: off many Sections? dsec=',num2str(dsec)])
%         end
        if ismember(dsec,delTvals)
            disp(['Extra data: Jumped to next Section'])
        elseif ismember(dsec,[delTvals+header_diff1, delTvals+header_diff2]) 
            disp(['Missing data: Skip to 2nd next Section'])
            csection = csection + 1;
        else 
            disp(['Triton Error: off many Sections? dsec=',num2str(dsec)])
        end
        % save info on sync loss
        PARAMS.hrp.ecntr(2) = PARAMS.hrp.ecntr(2)+1;
        PARAMS.hrp.decompErrors(PARAMS.hrp.ecntr(2),1:7) = ...
            [ 1, csection0-1, rpos, dsec0, csection, ftell(fid) - 8 - rfStartByte,...
            ddnum ];
                    
    end % end if sync loss
    csectInfo(csection,1) = dnum;
    csectInfo(csection,2) = sn1;
    
    dnumo = dnum;
    slen = fread(fid,1,'uint16');   % length in bytes of remaining Section
    % including slen
    rlen = slen;                    % remaining bytes in Section
    rlen = rlen - 2;                % decrement after fread
    samp1 = fread(fid,1,'int16');   % first sample of Section
    rlen = rlen - 2;
    bn = 0;     % block number
    ldata = 0;  % last data value
    nsamp = 0;  % total number of samples in a Section from Block writes
    % loop over blocks of compressed data until next Section
    if dbflag;fprintf('\t\tcsection = %d ----------\n',csection);end
    
    while rlen > 0
        nBlksPerRawFile = nBlksPerRawFile + 1;  % count number of blocks per raw file
        bn = bn + 1;
        if bn == 1
            sdata = samp1;
        else
            sdata = ldata;
        end
        data = [];
        ddata = [];
        
        if dbflag;fprintf('\t\tbn = %d\n\t\tslen = %d\n\t\trlen = %d\n\t\tsamp1 = %d\n\t\tnsamp = %d\n',...
            bn, slen, rlen, samp1, nsamp );end
        
        btag = fread(fid,1,'uint16');  % block tag
        rlen = rlen - 2;
        if dbflag;fprintf('\t\tbtag = %d\n', btag);end
        
        % read blocks
        if btag > 2^15             % check for 8-bit data
            blen = btag - 2^15 ;     % number of samples
            rleno = rlen;
            rlen = rlen - blen; 
            if rlen < 0             % this is the major problem with leading to 'sync losses'
                disp(['Error: block length too long: blen=',num2str(blen),' rlen=',num2str(rlen)])
                pos = ftell(fid);
                rpos = pos - rfStartByte;
                disp(['      csection= ',num2str(csection),' csector=  ',num2str(csector),...
                    ' ',datestr(dnum),' ',num2str(ticks),' bn= ',num2str(bn),...
                    ' Position= ',dec2hex(pos),' rlen0= ',num2str(rleno)])
                % the following is off by some samples...9 samples for
                % csection 2650, in raw file 13 of SOCAL_T_01_B disk02
                % blen/rleno = 1165, needs to be 1155 to make nsamp the
                % right value, but is the correct value for the number of
                % bytes to skip to the next section header...
                fsamps = 4000-nsamp;
                blen = rleno;
                rlen = 0;
                disp(['Truncate: blen=',num2str(blen),' rlen=',num2str(rlen)])
                disp(' ')
                
                offset = -samp1;    % need neg since differencing 8-bit
                if blen ~= fsamps
                    fprintf('fixed number of samples = %d should be = %d...truncating\n', ...
                    blen, fsamps);
                    ddata = offset .* ones(fsamps,1); % force samples to one value, flat line   
                else
                    ddata = offset .* ones(blen,1); % force samples to one value, flat line
                end
                fseek(fid,blen,0);      % skip over remaining bytes
                
                %save info on compression error
                PARAMS.hrp.ecntr(2) = PARAMS.hrp.ecntr(2)+1;
                PARAMS.hrp.decompErrors(PARAMS.hrp.ecntr(2),1:6) = ...
                    [ 3, csection, rpos, btag, rleno, fsamps ];
            else
                % normal operation
                if ftype == 1 % if USB
                    if rem(blen,2) % if odd
                        A = fread(fid,blen+1,'int8');   % read in differenced data vector
                        B = reshape(A,2,(blen+1)/2);    % convert to matrix
                        C = [B(2,:); B(1,:)];           % reordered - byte swap for 8-bit
                        D = reshape(C,blen+1,1);        % back to vector
                        ddata = D([1:end-2,end]);       % remove extra zero
                        if rlen ~= 0
                            rlen = rlen - 1;            % one less byte to read
                        else
                            fseek(fid,-1,0);            % skip back one byte if end of section
                        end
                    else  % if even
                        A = fread(fid,blen,'int8');     % read in differenced data
                        B = reshape(A,2,blen/2);        % convert to matrix
                        C = [B(2,:); B(1,:)];           % reordered - byte swap for 8-bit
                        ddata = reshape(C,blen,1);      % back to vector
                    end
                else % if FTP
                    if rem(blen,2) % if odd
                        A = fread(fid,blen+1,'int8');     % read in differenced data
                        ddata = A([1:end-2,end]);         % remove extra zero
                        if rlen ~= 0
                            rlen = rlen - 1;                % one less byte to read
                        else
                            fseek(fid,-1,0);                % skip back one byte if end of section
                        end
                    else  % if even
                        ddata = fread(fid,blen,'int8');     % read in differenced data
                    end
                end
            end
            if vflag == 1   % V2.02R and beyond ?
                data = cumsum([sdata,-ddata']);       % uncompress
            end
        else
            % 16-bit data
            blen = btag;                        % number of samples
            rleno = rlen;                       % hold on to previous remaining bytes in section
            rlen = rlen - 2*blen;                   % remaining bytes in Section
            if rlen < 0        % this is the major problem leading to 'sync losses'
                disp(['Error: block length too long: blen=',num2str(blen),' rlen=',num2str(rlen)])
                pos = ftell(fid);
                disp(['      csection= ',num2str(csection),' csector=  ',num2str(csector),...
                    ' ',datestr(dnum),' ',num2str(ticks),' bn= ',num2str(bn),...
                    ' Position= ',dec2hex(pos)])
                fsamps = 4000-nsamp;
                blen = floor(rleno/2);
                rlen = 0;
                disp(['Truncate: blen=',num2str(blen),' rlen=',num2str(rlen)])
                disp(' ')
                offset = samp1;
                if blen ~= fsamps
                    fprintf('fixed number of samples = %d should be = %d...truncating\n', ...
                    blen, fsamps);
                    ddata = offset .* ones(fsamps,1); % force samples to one value, flat line   
                else
                    ddata = offset .* ones(blen,1); % force samples to one value, flat line
                end
                fseek(fid,blen*2,0);      % skip over remaining bytes
                %save info on compression error
                PARAMS.hrp.ecntr(2) = PARAMS.hrp.ecntr(2)+1;
                PARAMS.hrp.decompErrors(PARAMS.hrp.ecntr(2),1:6) = ...
                    [ 3, csection, rpos, btag, rleno, fsamps ];                
            else
                ddata = fread(fid,blen,'int16');     % read in differenced data
            end
            
            if vflag == 1   % V2.02R
                data = [sdata,ddata'];       % uncompress
            end
        end  % end if btag > 2^15
        
        if vflag == 0   % V2.02Q
            data = cumsum([sdata,-ddata']);
        end
        
        dlen = length(data);
        ldata = data(dlen);         % save for seed of next block
        
        if bn > 1
            data = data(2:dlen);        % remove seed data
        end
        
        % V2.02Q bug: 16-bit differences can make output data
        % > 2^15 or < -2^15 beyond int16 range
        %
        % solution: find when this happens and set data to 16bit
        % difference
        I = [];
        I = find(data > 2^15 | data < -2^15);
        if ~isempty(I)
            disp(['Error: decompressed data beyond 16-bit limit ',...
                datestr(dnum),' ',num2str(ticks)])
            disp([' sector ',num2str(csector), ...
                ' section ' ,num2str(csection), ...
                ' block ',num2str(bn), ...
                ' btag ',num2str(btag),...
                ' blen ', num2str(blen),...
                ' samples ' ,num2str(length(I))])
            
            rpos = ftell(fid)-rfStartByte;
            
            %save info on compression error
            PARAMS.hrp.ecntr(2) = PARAMS.hrp.ecntr(2)+1;
            PARAMS.hrp.decompErrors(PARAMS.hrp.ecntr(2),1:5) = ...
                [ 4, csection, rpos, length(I),btag ];
            
            % set data to differences, essentually setting the seed
            % to zero which will result in some offset
            data = -ddata(1) .* ones(dlen-1,1);
            ldata = data(dlen-1);
            
            J = [];
            J = find(data > 2^15 | data < -2^15);
            if ~isempty(J)
                disp('ERROR: this should not happen')
                disp([' samples ' ,num2str(length(J))])
            end
            
        end
        
        % output data
        sdlen = length(data);
        odata(sn1:sn1+sdlen-1) = data;      % fill up output data vector
        
        if dbflag;fprintf('\t\tsize ddata = %d %d \n', size(ddata,1), size(ddata,2));         
        fprintf('\t\tsize data = %d %d \n',size(data,1), size(data,2));
        fprintf('\t\tsample0 = %d\n\t\tsampleN = %d\n',sn1, sn1+sdlen-1); 
        fprintf('\t\tsdlen = %d\n\n', sdlen);end
        
        %                 if rem(length(data),4) == 0
        %                     datamat = reshape(data,4,length(data)/4)';
        %                     nz21 = length(find((datamat(:,2)-datamat(:,1))==0));
        %                     nz32 = length(find((datamat(:,3)-datamat(:,2))==0));
        %                     nz43 = length(find((datamat(:,4)-datamat(:,3))==0));
        %                     nz14 = length(find((datamat(2:end,1) - datamat(1:end-1,4))==0));
        % %                     fprintf('csection = %d\tnz21 = %d\tnz32 = %d\tnz43 = %d\tnz14 = %d\n',...
        % %                         csection, nz21, nz32, nz43, nz14) ;
        %                     fprintf('nz21 = %d\tnz32 = %d\tnz43 = %d\tnz14 = %d\n',...
        %                         nz21, nz32, nz43, nz14) ;
        %                 end
        sn1 = sn1+sdlen;        % for the next section
        
        dlen = length(data);
        csectInfo(csection,3) = sn1-1;
        nsamp = nsamp + dlen;       % Total number of sample written for each Block
        
        if rlen == 0       % done with this Section
            tlen = slen + 8;       % total number of bytes of section including
            % timing header
            rbytes = rem(tlen,bpsect);  % remainder number of bytes in sector
            sbytes = bpsect - rbytes;  % bytes to skip over to next sector
            %                         rdata = fread(fid,sbytes,'uint8');  % test read
            if sbytes < bpsect && sbytes > 0
                fseek(fid,sbytes,0);      % skip over remaining bytes at
            elseif sbytes ~= bpsect && sbyte ~= 0
                disp('Triton ERROR: incorrect number of bytes to skip before next Section')
                disp(['Skip bytes = ',num2str(sbytes)])
            end
            % end of last sector of current
            % section

%             csector = csector + ceil(tlen/bpsect);  % number of sectors used in this disk dump/write
%             cslSect = cyy/bpsect; % scanned sync loss sectors
%             if rem(cslSect,1)~=0
%                 fprintf('\tDid not scan a whole number of sectors for sync loss!\n');
%                 fprintf('\tScanned %d bytes, %f sectors\n', cyy, cslSect);
% %                 cslSect = ceil(cslSect)*bpsect;'
%                 cslSect = floor(cslSect);
%                 fprintf('\tRounding to %d sectors\n', cyy, cslSect);
%             end
%             csector = csector + ceil(tlen/bpsect) + cslSect; % add in sync loss scanned sectors 
            
%             cyy = 0;
            csector = csector + ceil(tlen/bpsect);  % number of sectors used in this disk dump/write
            
            break       % break out of while rlen loop
        end  % end if rlen == 0
    end % end while rlen
    
    % hack to fix data
    % if too many samples, truncate and break from while csector loop
%     if length(odata) > Tnsamp
%         odata = odata(1:Tnsamp);
%         break           % break out of while csector, effectively ending function call
%     end

end % end while csector