function [ ndata, newTime0, nGoodSamp, BWAdata, BWAcsectInfo ] = fixBWA_170816(rf,fid,odata, csectInfo, BWAdata, BWAcsectInfo)

global PARAMS

numRFnext = 1;
mnum2secs = 24*60*60;

%fix clock jitter
csectInfo0 = csectInfo;
jval = 1.02; % jitter value in seconds ( 200kHz only );
diff_thdrs = round(diff(csectInfo(:,1))*mnum2secs*1e6)/1e6; % round to microseconds

% find section delta t with clock jitter and replace with correct value
%
jidx = find(diff_thdrs == jval)+1;
csectInfo(jidx,1) = csectInfo(jidx,1) - datenum([ 0 0 0 0 0 1 ]);
diff_thdrs = diff(csectInfo)*mnum2secs;

BWAdata0 = BWAdata; % 0-> current file, new BWAdata saved for next file
BWAcsectInfo0 = BWAcsectInfo;
% detect BWA
bwIdx = find( diff_thdrs <= -2*(1.02) ); % maybe be explicit about timing matches for standard BWA
if isempty(bwIdx)
    ndata = odata;
    newTime0 = csectInfo(1); 
    nGoodSamp = length(odata);
    BWAdata = [];
    BWAcsectInfo = [];     
    return % no BWA, life is good
elseif length(bwIdx)>1
    fprintf('More than one BW found....panic!');  
    return
elseif length(bwIdx) == 1
    % put BWA data somewhere else for use in next file
    BWAcsectInfo = csectInfo(1:bwIdx,:); % assume when BWA happens, always from start of RF
    if unique(diff(BWAcsectInfo(:,3))) ~= 4000 % check that our section lenghts are a FIFO buffer long
        fprintf('BWA sections not FIFO buffer apart...need a better fix...\n');
        return
    else
        BWAdata = odata(BWAcsectInfo(1,2):BWAcsectInfo(end,3)); % should put in a check that sample indexes start at 1...
        odata(BWAcsectInfo(1,2):BWAcsectInfo(end,3)) = []; % remove wrapped data from current raw file data
        csectInfo = csectInfo(bwIdx+1:end,:);
        csectInfo(:,2:3) = csectInfo(:,2:3) - BWAcsectInfo(end,3); % change sample offsets since we removed BWA data
        % put in BWA data from last if it exists
        if ~isempty(BWAdata0)
            nonDupBWA = find(~ismember(BWAcsectInfo0(:,1),csectInfo(:,1))); % non duplicated BWA sections
            dupBWA = find(ismember(BWAcsectInfo0(:,1),csectInfo(:,1)));
            BWAcsectDupInfo0 = BWAcsectInfo0(dupBWA,:); % save info on duplicate data for plotting
            BWAcsectInfo0 = BWAcsectInfo0(nonDupBWA,:);
            % remove duplicate samples from timeseries data
            if unique(diff(BWAcsectInfo0(:,3))) ~= 4000 % doing this again until we need to do better
                fprintf('Unique BWA sections not FIFO buffer apart...need a better fix...\n'); % data should be sequential for the systemic BWA problem
                return
            elseif isempty(nonDupBWA)
                fprintf('No unique BWA data from last raw file...\n');       
            else
                BWAdata0 = BWAdata0(BWAcsectInfo0(1,2):BWAcsectInfo0(end,3));
                csectInfo(:,2:3) = csectInfo(:,2:3)+BWAcsectInfo0(end,3); % shift current data's sample nums since we're inserting data
                odata = [ BWAdata0; odata ]; % usually BWA data from last RF should be at the beginning of current RF
                csectInfo = [  BWAcsectInfo0; csectInfo ];
            end
        end
    end
end

% sort data that should be in current RF, includes buffer wrapped data
% from last raw file
[ ~, sorti ] = sort(csectInfo(:,1)*mnum2secs);
csectInfo = csectInfo(sorti,:);
lastSectRF1 = size(csectInfo,1);   % last section in raw file with fixed data

% read in subsequent raw files to look for duplicated data
ncsectInfo = [];
for rfn = 1:numRFnext
%     [ ndataTemp, csectInfoTemp ] = decompressRawHRP_170607(fid, ...
%         rf+rfn,PARAMS.ctype);
    csectInfoTemp = getSectionTimes_170824(fid,rf+rfn);
    ncsectInfo = [ ncsectInfo; csectInfoTemp ];
end

csectNextInfo = [ csectInfo(:,:); ncsectInfo(:,:) ]; % section info for current and subsequent raw files
% find sect Times that are not duplicated
% ...limitation of histc/histcounts is it will sort data first...will
% need to keep track of sorting to convert back to what we want
[ csectNextTimesSorted, us2s ] = sort(csectNextInfo(:,1));
[ ucsectNextTimes, f2u, u2f ] = unique(csectNextTimesSorted);
dupCounts = hist(csectNextTimesSorted, ucsectNextTimes);
dupCountsUnsorted = zeros(length(us2s),1);
% unsort data...we'll use this to avoid using data from subsequent raw
% flies
dupCountsUnsorted(us2s) = dupCounts(u2f);
% want only unique section times from current raw file ( including BWA data from previous raw file )
DupIdxs = find(dupCountsUnsorted==1);
rf1Idxs = find(DupIdxs <= lastSectRF1 );

sidx=1; eidx=0;
nGoodSamp = sum(csectInfo(rf1Idxs,3)-csectInfo(rf1Idxs,2)+1);
    nOrigSamp = sum(csectInfo0(:,3)-csectInfo0(:,2)+1);
% nOrigSamp = sum(csectInfo0(:,3)-(csectInfo0(:,2));
nLostSamp = nOrigSamp - nGoodSamp;
ndata = nan(nGoodSamp,1);

% if rf == 25650
%     disp('!')
% end
for csi=1:length(rf1Idxs)
    cs = rf1Idxs(csi); % section number
    eidx = sidx + csectInfo(cs,3) - csectInfo(cs,2);
    ndata(sidx:eidx) = odata(csectInfo(cs,2):csectInfo(cs,3));
    sidx = eidx+1;
    %         fprintf('\tsection\t%d\t=\t%s\t[\t%d\t-\t%d\t]\n', ...
    %             cs, ...
    %             datestr(csectInfo(cs,1),'mm/dd/yy HH:MM:SS.FFF'), ...
    %             csectInfo(cs,2), ...
    %             csectInfo(cs,3));
end
fprintf('Number of retained samples = %d = %.6f seconds\n', nGoodSamp, nGoodSamp/PARAMS.head.samplerate);
fprintf('Number of lost samples = %d = %.6f seconds\n', nLostSamp, nLostSamp/PARAMS.head.samplerate);

% save BWA error info
PARAMS.hrp.ecntr(3) = PARAMS.hrp.ecntr(3)+1;
PARAMS.hrp.BWA(PARAMS.hrp.ecntr(3),:) = [ rf, bwIdx, nGoodSamp, nLostSamp, csectInfo(bwIdx-1,1),csectInfo(bwIdx,1) ];

newTime0 = csectInfo(1);