function stime = getSectionTimes_170824(fid,rf)
%
% operates on individual raw files
%
% 170607 smw
%
% added check for sync losses and now returns sample counts
%
% 170828 bjt
global PARAMS

bpsect = 512;       % bytes per sector
nsprf = 3750;       % number of sections per raw file
ADCbfrz = 4000; % samples / buffer, one buffer = 1 section

stime = zeros(nsprf,3); % pre-allocate section time vector


% skip to start of raw file
status = fseek(fid,PARAMS.head.dirlist(rf,1)*bpsect,'bof'); %#ok<NASGU>
Nsect = PARAMS.head.dirlist(rf,10);
% samplerate = PARAMS.head.samplerate;

ftype = 1;

csector = 0;              % sector count
csection = 0;           % section count
sampCounter = 1;
% loop over sectors in raw file
% typically there will be multiple number of sectors (=>8) in ea
% Section, so kinda looping over Sections in integer number of
% sectors

dvo = [PARAMS.head.dirlist(rf,2:6) ...
    PARAMS.head.dirlist(rf,7)+0.001*PARAMS.head.dirlist(rf,8)];
dnum = datenum(dvo);       % first old datenum is dirlist time
rfStartByte = PARAMS.head.dirlist(rf,1)*bpsect;
rfSz = PARAMS.head.dirlist(rf,end);    
while csector < Nsect
    csection = csection + 1;
    dnumo = dnum;
    [dv,dcount] = fread(fid,8,'uint8');
    posRel = ftell(fid)-rfStartByte; 
    % the following shouldn't be needed except for perhaps last file
    % left over from hrp2xwav on single ftp/usb raw files
    if dcount ~= 8
        disp('*************** EOF - Stopped Writing XWAV *******************')
        disp(['only read ',num2str(dcount),' values for timing header'])
        disp('Since less than 8, must be EOF')
        [msg,errnum] = ferror(fid);
        disp(['msg= ',msg,'  errnum= ',num2str(errnum)])
        break       % break out of while csector
    end
    if ftype == 1
        ticks = (little2big_2byte([dv(8) dv(7)]));
        dnum = datenum([dv(2) dv(1) dv(4) dv(3) dv(6) dv(5)+ 0.001.* ticks]);
    elseif ftype == 2
        ticks = 2^8*dv(7)+ dv(8);
        dnum = datenum([dv(1) dv(2) dv(3) dv(4) dv(5) dv(6)+ 0.001.* ticks]);
    end
    
    pos0 = ftell(fid);
    [ dnum, fid,csection ] = checkSectionTime(fid, ftype, dnum, dnumo, csection, csector,rfStartByte,rf);
    cslOffset = ftell(fid) - pos0;
    cslSect = cslOffset/bpsect; % scanned sync loss sectors
    if rem(cslSect,1)~=0
        fprintf('\tDid not scan a whole number of sectors for sync loss!\n');
        fprintf('\tScanned %d bytes, %f sectors\n', cyy, cslSect);
        cslSect = ceil(cslSect)*bpsect;
        fprintf('\tRounding to %d bytes, %f sectors\n', cslSect*bpsect, cslSect);
    end
    slen = fread(fid,1,'uint16');   % length in bytes of remaining Section
    fseek(fid,-10,0);       % rewind back to beginning of section
    nrsect = ceil((slen+10-2)/bpsect);
    fseek(fid,nrsect*512,0);    % integer number of sectors for each section
    csector = csector + nrsect + cslSect;

    stime(csection,1) = dnum;
    stime(csection,2) = sampCounter;
    stime(csection,3) = sampCounter+ADCbfrz-1;
    sampCounter = sampCounter+ADCbfrz;
%     fprintf('\t\t---------------------> section #%d sector #%d cslOffset %d max sector = %d\n',...
%        csection, csector, cslOffset,Nsect);
        
end % end while csector

end 

function [ dnum, fid,csection ] = checkSectionTime(fid, ftype, dnum, dnumo, csection, csector,rfStartByte,rf)
    global PARAMS
    
   
    ddnum = dnum - dnumo;   % difference in datenum new - old
    dsec = ddnum * 24 * 60 * 60;        % section header times should be 0.020 sec apart
    dsec = round(1000*dsec)/1000;
    
    % bug in decompression firmware adds a second every 50(?)
    % sections...these delta t's are NOT real timing errors
    % they come from (fs/4000) +/- [ 0/1 second ]
    
    % 1.020 and -0.98 are from 2.02Q.
    % .013 & .012 is from 2.05A (320KHz)
    % 320KHz requires extra checks due to DL rounding off
    % millisecond fractions
    
    edts = [ .02, 1.02, -.98, 0, ...
        .012, .013, 1.012, 1.013, -0.987, -0.988 ];
    
    % could put a check for samplerate in here...but unlikely it would be
    % needed

    delTerr = 0;
    if ~ismember(dsec,edts)
        delTerr = 1;
    end
 
    if delTerr    
        fprintf('\tTriton Error: Time difference between section headers is %6f\n', dsec); 
        fprintf('\t\tt1 = %s\n\t\tt2 = %s\n', ...
            datestr(dnumo,'yy mm dd HH MM SS FFF'),datestr(dnum,'yy mm dd HH MM SS FFF'));
        fprintf('\t\tcsection #%d, bytes to current section = %d\n', ...
            csection, ftell(fid)-rfStartByte);
    end
    
    % omit buffer wrap time -81.9s, as this is not a 'sync' loss
    dmin = -100;
    dmax = 100;
    if (dsec < dmin) || (dsec > dmax)   % if sync loss
        % save info on sync loss
        PARAMS.error.csl = PARAMS.error.csl + 1;    % count
        PARAMS.error.slrf(PARAMS.error.csl) = rf;   % rawfile #
        
        % give some feed back
        pos = ftell(fid);        
%         fprintf('\tTriton Error: sync loss @ sector = %d, section = %d\n', ...
%             csector, csection);
        fprintf('\tPosition = %d [ dec bytes ] || %s [ hex bytes ]\n', ...
            pos,dec2hex(pos));
%         fprintf('\tPrevious datetime: %s\n', ...
%             datestr(dnumo,'yy mm dd HH MM SS FFF'));
%         fprintf('\tCurrent datetime: %s\n', ...
%             datestr(dnum,'yy mm dd HH MM SS FFF'));
%         fprintf('\tdiff t = %.6f [ seconds ]\n', dsec);              
        
        % search for next section timing header sync
        cyy = 0;
        while dsec < dmin || dsec > dmax
            fseek(fid,-7,0); % go back 7 bytes so that each read only advances 1 byte
            dv = fread(fid,8,'uint8');
            if ftype == 1
                ticks = (little2big_2byte([dv(8) dv(7)]));
                dnum = datenum([dv(2) dv(1) dv(4) dv(3) dv(6) dv(5)+ 0.001.* ticks]);
            elseif ftype == 2
                ticks = 2^8*dv(7)+ dv(8);
                dnum = datenum([dv(1) dv(2) dv(3) dv(4) dv(5) dv(6)+ 0.001.* ticks]);
            end
            ddnum = dnum - dnumo;   % difference in datenum new - old
            dsec = ddnum * 24 * 60 * 60;        % section header times should be 0.020 sec apart
            dsec = round(1000*dsec)/1000;
            cyy = cyy + 1;
            if cyy >= 30e6
                disp('stepping too far - exit')
                return
            end
        end  % end while
        
        fprintf('\tjumped ahead %d bytes to next timestamp\n', cyy);
        fprintf('\tnew timestamp = %s\n', datestr(dnum,'yy mm dd HH MM SS FFF'));
        if ismember(dsec, [0.020, 0.012, 0.013])
            disp('Extra data: Jumped to next Section')
        elseif ismember(dsec ,2*[0.020, 0.012, 0.013])
            disp('Missing data: Skip to 2nd next Section')
            csection = csection + 1;
        else
            fprintf('\Triton Error: off many sections? dsec = %.6f\n', dsec);
        end       
    end % end if sync loss
end